@@ -1,20 +1,8 @@
 /*
- * Copyright (C) 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 // own
 #include "board.h"
@@ -92,7 +80,7 @@ void BomberBoard::resize(QSize & size)
 
     m_tileSize = QSize(minTileSizeWidth, minTileSizeHeight);
 
-    foreach (Building * building, m_buildings) {
+    for (Building * building : qAsConst(m_buildings)) {
         building->resize(m_tileSize);
     }
 
@@ -172,7 +160,7 @@ void BomberBoard::tick()
         m_bomb->advanceItem();
     }
 
-    foreach (Bomb * bomb, m_explodingBombs) {
+    for (Bomb * bomb : qAsConst(m_explodingBombs)) {
         bomb->advanceItem();
     }
 
@@ -183,7 +171,7 @@ void BomberBoard::tick()
         m_bomb->update();
     }
 
-    foreach (Bomb * bomb, m_explodingBombs) {
+    for (Bomb * bomb : qAsConst(m_explodingBombs)) {
         bomb->update();
     }
 }
@@ -200,7 +188,8 @@ void BomberBoard::dropBomb()
 
 void BomberBoard::checkCollisions()
 {
-    foreach (Building * building, m_buildings) {
+    const auto currentBuildings = m_buildings;
+    for (Building * building : currentBuildings) {
         if (m_plane->nextBoundingRect().intersects(building->boundingRect()) && m_plane->state() == Explodable::State::Moving) {
             // Plane crashed into the building
             building->destoryTop();
@@ -213,7 +202,7 @@ void BomberBoard::checkCollisions()
                 // Bomb hit a building
                 building->destoryTop();
                 --m_buildingBlocks;
-                emit onBombHit();
+                Q_EMIT onBombHit();
                 bombHit(m_bomb, building->position().x(), Building::BUILD_BASE_LOCATION - (building->height()));
                 m_bomb = nullptr;
             } else if (m_bomb->position().y() >= Building::BUILD_BASE_LOCATION + 1) {
@@ -224,7 +213,7 @@ void BomberBoard::checkCollisions()
         }
 
         if (m_plane->state() == Explodable::State::Moving && m_buildingBlocks == 0) {
-            emit levelCleared();
+            Q_EMIT levelCleared();
         }
     }
 }
@@ -235,7 +224,7 @@ void BomberBoard::bombHit(Bomb * bomb, qreal moveBombToX, qreal moveBombToY)
     bomb->setState(Bomb::State::Exploding);
     m_explodingBombs.enqueue(bomb);
     QTimer::singleShot(BOMB_EXPLODE_TIME, this, &BomberBoard::bombExploded);
-    emit playBombSound();
+    Q_EMIT playBombSound();
 }
 
 void BomberBoard::bombExploded()
@@ -254,7 +243,7 @@ void BomberBoard::settingsChanged()
 void BomberBoard::planeExploded()
 {
     m_plane->setState(Plane::State::Exploded);
-    emit onPlaneCrash();
+    Q_EMIT onPlaneCrash();
 }
 
 void BomberBoard::crashed()
@@ -263,7 +252,7 @@ void BomberBoard::crashed()
     m_plane->setPosition(pos.x() + 1, pos.y());
     m_plane->setState(Plane::State::Exploding);
     QTimer::singleShot(PLANE_EXPLODE_TIME, this, &BomberBoard::planeExploded);
-    emit playCrashSound();
+    Q_EMIT playCrashSound();
 }
 
 void BomberBoard::clear()
