@@ -1,25 +1,16 @@
 /*
- * Copyright (C) 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007-2008 John-Paul Stanford <jp@stanwood.org.uk>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #ifndef BOMBER_H
 #define BOMBER_H
 
-// KDE
+// KF
 #include <KXmlGuiWindow>
+
+// KDEGames
 #include <KgThemeProvider>
 
 // Bomber
@@ -42,7 +33,7 @@ class Bomber : public KXmlGuiWindow
     Q_OBJECT
 public:
     Bomber();
-    virtual ~Bomber();
+    ~Bomber() override;
 
     void readSettings();
 
@@ -51,6 +42,7 @@ private Q_SLOTS:
     void newGame();
     void pauseGame();
     void showHighscore();
+    void showPreferences();
 
     void displayLevel(unsigned int level);
     void displayScore(unsigned int score);
@@ -60,7 +52,6 @@ private Q_SLOTS:
 private:
     void highscore();
     void initXMLUI();
-    void setupActions();
 
     KgThemeProvider m_provider;
     KgThemeSelector * m_selector;
